write

Function write 

pub unsafe fn write(
    fault_backend: &Backend,
    target_value: *mut PrimitiveUnion,
    target_source: *const PrimitiveUnion,
    target_type: Primitive,
) -> catalejo_outcome_t
Perform a bare-bones primitive write via the C-implemented shims.

Safety

This has the same safety constraints as an individual binding::catalejo_write_uN operation, where N is the size of the primitive written. fault_backend must belong to the current process before a fault can occur.