pub enum SlabAllocationError {
SoftLimitReached,
System(Error),
}Expand description
A failure while allocating an exception slab.
Variants
SoftLimitReached
The context already owns its configured number of userspace slabs.
System(Error)
The operating system rejected or malformed the slab mapping.