Context

Struct Context 

pub struct Context(/* private fields */);
An fd-owned exception context bound to its creating address space.

Implementations

Source

impl Context

pub unsafe fn create( device: BorrowedFd<'_>, slab_size: SlabSize, soft_limit: SoftSlabLimit, ) -> Result<Self>

Create the one exception context allowed for the current address space.

Safety

device must be a descriptor created by Mirilla.

Errors

This returns a kernel error or an invalid successful result from the foreign interface.

pub const fn id(&self) -> ExceptionId

Return the kernel identifier.

pub const fn slab_size(&self) -> SlabSize

Return the configured slab size.

pub const fn soft_limit(&self) -> SoftSlabLimit

Return the configured userspace slab limit.

pub fn allocated(&self) -> usize

Return the number of currently mapped slabs.

pub fn map(&self) -> Result<Slab<'_>, SlabAllocationError>

Map one editable exception slab.

Errors

This fails when the userspace soft limit is reached or the operating system rejects the mapping.