Module monitor

Module monitor 

Protected hardware monitor instruction support.

Enums

MonitorBackend
A hardware implementation for monitoring an address.
MonitorError
A failure while arming or waiting with a hardware monitor.

Functions

arm⚠
Arm the selected hardware monitor for an address.
backend
Determine the runtime selected hardware monitor implementation.
wait⚠
Wait for one bounded interval with an armed hardware monitor.