pub enum MonitorError {
Fault,
Unsupported,
}Expand description
A failure while arming or waiting with a hardware monitor.
Variants
Fault
The monitored local address faulted while it was being armed.
Unsupported
The selected optional instruction is unavailable at runtime.