Module command

Module command 

Commands for userspace-kernel device ioctls.

Constants

MIRILLA_DEVICE_NAME
The canonical name of the device exposed by the kernel module.

Functions

address_space_layout⚠
For an engaged target process, retrieve the full address space layout, the kernel-resident auxiliary vector, and the argument/environment metadata.
default_device_path
Determine the optionally configured default path to the kernel character device.
disengage⚠
Disengage from the target process.
engage⚠
Engage with the target process.
peephole⚠
For an engaged target process, create a peephole over the specified virtual memory range.