pub type AddressSpaceLayout = mirilla_map_address_space_layout;Expand description
A single address space layout entry, as returned by a layout query.
Aliased Type
#[repr(C)]pub struct AddressSpaceLayout {
pub start_address: u64,
pub end_address: u64,
pub attribute_list: u32,
pub file_offset: u64,
pub device_major: u32,
pub device_minor: u32,
pub inode_number: u64,
}Fields
start_address: u64The start and end virtual address pair.
end_address: u64The start and end virtual address pair.
attribute_list: u32The attribute list for this portion of the address space.
file_offset: u64Byte offset in the backing file when MIRILLA_MAP_LAYOUT_ATTRIBUTE_FILE is set.
device_major: u32Device identity of the backing inode when the file attribute is set.
device_minor: u32Device identity of the backing inode when the file attribute is set.
inode_number: u64Inode number of the backing file when the file attribute is set.