pub unsafe fn wait( fault_backend: &Backend, backend: MonitorBackend, ) -> Result<(), MonitorError>
Wait for one bounded interval with an armed hardware monitor.
The backend must come from the immediately preceding successful arm call on this thread. The monitored mapping must remain live. The fault backend must belong to the current process.
arm